"use strict";

var _interopRequireWildcard = require("@babel/runtime-corejs2/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLuma = getLuma;
exports.getTheme = getTheme;
exports.default = exports.GeoJSONTransform = void 0;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/toConsumableArray"));

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/classCallCheck"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/createClass"));

var _possibleConstructorReturn2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/possibleConstructorReturn"));

var _getPrototypeOf3 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/getPrototypeOf"));

var _inherits2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/inherits"));

var _assertThisInitialized2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/assertThisInitialized"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/defineProperty"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/slicedToArray"));

var React = _interopRequireWildcard(require("react"));

var _leaflet = _interopRequireDefault(require("leaflet"));

/* eslint class-methods-use-this: 0 */
var MIMETYPE = "application/geo+json";
_leaflet.default.Icon.Default.imagePath = "../node_modules/leaflet/dist/images/";

function getLuma(el) {
  // https://en.wikipedia.org/wiki/Luma_(video)
  var style = window.getComputedStyle(el);

  var _style$backgroundColo = style.backgroundColor.replace(/^(rgb|rgba)\(/, "").replace(/\)$/, "").replace(/\s/g, "").split(","),
      _style$backgroundColo2 = (0, _slicedToArray2.default)(_style$backgroundColo, 3),
      r = _style$backgroundColo2[0],
      g = _style$backgroundColo2[1],
      b = _style$backgroundColo2[2]; // Digital ITU BT.601
  // http://www.itu.int/rec/R-REC-BT.601


  var y = 0.299 * r + 0.587 * g + 0.114 * b;
  return y / 255;
}

function getTheme() {
  var theme = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "light";
  var el = arguments.length > 1 ? arguments[1] : undefined;

  switch (theme) {
    case "light":
    case "dark":
      return theme;

    default:
      if (getLuma(el) < 0.5) {
        return "dark";
      }

      return "light";
  }
}

var GeoJSONTransform =
/*#__PURE__*/
function (_React$Component) {
  (0, _inherits2.default)(GeoJSONTransform, _React$Component);

  function GeoJSONTransform() {
    var _getPrototypeOf2;

    var _this;

    (0, _classCallCheck2.default)(this, GeoJSONTransform);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = (0, _possibleConstructorReturn2.default)(this, (_getPrototypeOf2 = (0, _getPrototypeOf3.default)(GeoJSONTransform)).call.apply(_getPrototypeOf2, [this].concat(args)));
    (0, _defineProperty2.default)((0, _assertThisInitialized2.default)((0, _assertThisInitialized2.default)(_this)), "getTileLayer", function () {
      if (!_this.el) return;
      var theme = getTheme(_this.props.theme, _this.el); // const urlTemplate = (this.props.metadata && this.props.metadata.url_template) ||
      //   'https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png';

      var urlTemplate = _this.props.metadata && _this.props.metadata.url_template || "https://api.tiles.mapbox.com/v4/{id}/{z}/{x}/{y}.png?access_token=pk.eyJ1IjoibWlja3QiLCJhIjoiLXJIRS1NbyJ9.EfVT76g4A5dyuApW_zuIFQ"; // const layerOptions = (this.props.metadata && this.props.metadata.layer_options) || {
      //   attribution: 'Map data (c) <a href="https://openstreetmap.org">OpenStreetMap</a> contributors',
      //   minZoom: 0,
      //   maxZoom: 18
      // };

      var layerOptions = _this.props.metadata && _this.props.metadata.layer_options || {
        attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a>',
        id: "mapbox.".concat(theme)
      };
      return [urlTemplate, layerOptions];
    });
    return _this;
  }

  (0, _createClass2.default)(GeoJSONTransform, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.map = _leaflet.default.map(this.el);
      this.map.scrollWheelZoom.disable();
      this.tileLayer = _leaflet.default.tileLayer.apply(_leaflet.default, (0, _toConsumableArray2.default)(this.getTileLayer())).addTo(this.map);
      var geoJSON = this.props.data;
      this.geoJSONLayer = _leaflet.default.geoJson(geoJSON).addTo(this.map);
      this.map.fitBounds(this.geoJSONLayer.getBounds());
    }
  }, {
    key: "shouldComponentUpdate",
    value: function shouldComponentUpdate(nextProps) {
      if (nextProps.theme !== this.props.theme || this.props.data !== nextProps.data) {
        return true;
      }

      return false;
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      if (prevProps.theme !== this.props.theme) {
        this.map.removeLayer(this.tileLayer);
        this.tileLayer = _leaflet.default.tileLayer.apply(_leaflet.default, (0, _toConsumableArray2.default)(this.getTileLayer())).addTo(this.map);
      }

      if (prevProps.data !== this.props.data) {
        var geoJSON = this.props.data;
        this.map.removeLayer(this.geoJSONLayer);
        this.geoJSONLayer = _leaflet.default.geoJson(geoJSON).addTo(this.map);
        this.map.fitBounds(this.geoJSONLayer.getBounds());
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      return React.createElement(React.Fragment, null, React.createElement("link", {
        rel: "stylesheet",
        href: "../node_modules/leaflet/dist/leaflet.css"
      }), React.createElement("div", {
        ref: function ref(el) {
          _this2.el = el;
        },
        style: {
          height: 600,
          width: "100%"
        }
      }));
    }
  }]);
  return GeoJSONTransform;
}(React.Component);

exports.GeoJSONTransform = GeoJSONTransform;
(0, _defineProperty2.default)(GeoJSONTransform, "defaultProps", {
  theme: "light"
});
(0, _defineProperty2.default)(GeoJSONTransform, "MIMETYPE", MIMETYPE);
var _default = GeoJSONTransform;
exports.default = _default;